[gimp] libgimp: fix docs of deprecated functions (cherry picked from commit 569c1221379b46f6391531bac6bd36f
- From: Michael Natterer <mitch src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] libgimp: fix docs of deprecated functions (cherry picked from commit 569c1221379b46f6391531bac6bd36f
- Date: Wed, 2 May 2012 22:27:02 +0000 (UTC)
commit 3d5758d209ede47dbfc9111c85e038391464f2ee
Author: Michael Natterer <mitch gimp org>
Date: Thu May 3 00:25:08 2012 +0200
libgimp: fix docs of deprecated functions
(cherry picked from commit 569c1221379b46f6391531bac6bd36f7decade08)
libgimp/gimpdrawable.c | 2 +-
libgimp/gimpimage.c | 4 ++--
2 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/libgimp/gimpdrawable.c b/libgimp/gimpdrawable.c
index 21f9a1d..00e1725 100644
--- a/libgimp/gimpdrawable.c
+++ b/libgimp/gimpdrawable.c
@@ -624,7 +624,7 @@ gimp_drawable_parasite_list (gint32 drawable_ID,
* Convenience function that creates a parasite and attaches it
* to GIMP.
*
- * Deprecated: use gimp_image_parasite_attach() instead.
+ * Deprecated: use gimp_item_attach_parasite() instead.
*
* Return value: TRUE on successful creation and attachment of
* the new parasite.
diff --git a/libgimp/gimpimage.c b/libgimp/gimpimage.c
index 5b6f35b..a1dc132 100644
--- a/libgimp/gimpimage.c
+++ b/libgimp/gimpimage.c
@@ -437,7 +437,7 @@ gimp_image_parasite_list (gint32 image_ID,
* Convenience function that creates a parasite and attaches it
* to GIMP.
*
* Deprecated: Use gimp_image_parasite_attach() instead.
*
* Return value: TRUE on successful creation and attachment of
* the new parasite.
@@ -454,7 +454,7 @@ gimp_image_attach_new_parasite (gint32 image_ID,
GimpParasite *parasite = gimp_parasite_new (name, flags, size, data);
gboolean success;
- success = gimp_image_parasite_attach (image_ID, parasite);
+ success = gimp_image_attach_parasite (image_ID, parasite);
gimp_parasite_free (parasite);
[
Date Prev][
@@ -437,7 +437,7 @@ gimp_image_parasite_list (gint32 image_ID,
* to GIMP.
*
- * Deprecated: Use gimp_image_parasite_attach() instead.
+ * Deprecated: Use gimp_image_attach_parasite() instead.
*
* Return value: TRUE on successful creation and attachment of
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]